@@ -38,8 +38,8 @@ export const DEFS = {
             light: "#deddda",
         },
         foreground: {
-            dark: "#ffffff",
-            light: "#000000",
+            dark: "#deddda",
+            light: "#3d3846",
         },
         water: {
             dark: "#0f2f5e",
@@ -158,8 +158,8 @@ export const DEFS = {
             classes: ["city"],
             font: "Bold",
             color: {
-                dark: "#ffffff",
-                light: "#000000",
+                dark: "#deddda",
+                light: "#3d3846",
             },
             minzoom: 4,
             maxzoom: 12,
@@ -173,8 +173,8 @@ export const DEFS = {
             classes: ["town", "village"],
             font: "Bold",
             color: {
-                dark: "#ffffff",
-                light: "#000000",
+                dark: "#deddda",
+                light: "#3d3846",
             },
             maxzoom: 13,
             sizeStops: [
@@ -209,6 +209,18 @@ export const DEFS = {
                 [15, 18],
             ],
         },
+        {
+            classes: ["isolated_dwelling"],
+            font: "Regular",
+            color: {
+                dark: "#c0bfbc",
+                light: "#5e5c64",
+            },
+            minzoom: 15,
+            sizeStops: [
+                [15, 15],
+            ],
+        },
         {
             id: "place-island-large",
             classes: ["island"],
@@ -318,9 +330,10 @@ export const DEFS = {
                 bus_station: ["bus-symbolic", "transport"],
                 cafe: ["cafe-symbolic", "food"],
                 car_rental: ["driving-symbolic", "transport"],
-                charging_station: ["electric-car-symbolic", "transport"],
+                charging_station: ["ev-symbolic", "transport"],
                 cinema: ["video-camera-symbolic", "generic"],
                 clinic: ["hospital-sign-symbolic", "healthAndSafety"],
+                clock: ["clock-alt-symbolic", "micro", 16],
                 college: ["school-symbolic", "education"],
                 conference_centre: ["meeting-symbolic", "public", 13],
                 dentist: ["dentist-symbolic", "healthAndSafety"],
@@ -350,6 +363,7 @@ export const DEFS = {
                 restaurant: ["restaurant-symbolic", "food"],
                 school: ["school-symbolic", "education"],
                 taxi: ["taxi-symbolic", "transportation", 16],
+                telephone: ["phone-oldschool-symbolic", "micro", 16],
                 theatre: ["theater-symbolic", "generic"],
                 toilets: ["toilets-symbolic", "micro", 16],
                 university: ["school-symbolic", "education", 13],
@@ -361,13 +375,16 @@ export const DEFS = {
                 cycle_barrier: ["gate-symbolic", "traffix", 17, 0.75],
                 gate: ["gate-symbolic", "traffic", 17, 0.75],
                 lift_gate: ["gate-symbolic", "traffic", 17, 0.75],
+                toll_booth: ["money-symbolic", "traffic", 17, 0.75],
             },
             building: {
                 railway_station: ["train-symbolic", "transport", 16],
                 _: ["building-symbolic", "generic", 16],
             },
             highway: {
+                bus_guideway: ["bus-symbolic", "transport", 16],
                 bus_stop: ["bus-symbolic", "transport", 16],
+                busway: ["bus-symbolic", "transport", 16],
                 cycleway: ["cycling-symbolic", "transport", 16],
                 footway: ["walking-symbolic", "transport", 16],
                 pedestrian: ["walking-symbolic", "transport", 16],
@@ -391,12 +408,12 @@ export const DEFS = {
                 dog_park: ["dog-symbolic", "parks"],
                 fitness_centre: ["weight2-symbolic", "generic"],
                 fitness_station: ["weight2-symbolic", "micro", 16],
-                garden: ["tree-symbolic", "parks", 16],
+                garden: ["leaf-symbolic", "parks", 16],
                 golf_course: ["golf-symbolic", "parks", 14],
                 mini_golf: ["golf-symbolic", "parks"],
                 miniature_golf: ["golf-symbolic", "parks"],
-                nature_reserve: ["tree-symbolic", "parks", 10],
-                park: ["tree-symbolic", "parks", 10],
+                nature_reserve: ["sprout-symbolic", "parks", 10],
+                park: ["tree-circle-symbolic", "parks", 10],
                 pitch: ["@sport", "parks", 16],
                 playground: ["playground3-symbolic", "parks", 16],
                 sports_centre: ["@sport", "parks", 13],
@@ -431,12 +448,12 @@ export const DEFS = {
                 village: ["town-symbolic"],
             },
             railway: {
-                halt: ["train-symbolic", "transport", 16],
-                station: ["train-symbolic", "transport", 16],
-                stop: ["train-symbolic", "transport", 16],
+                halt: ["@station", "transport", 12],
+                station: ["@station", "transport", 10],
+                stop: ["@station", "transport", 12],
                 subway_entrance: ["exit-symbolic", "transport", 16],
                 train_station_entrance: ["exit-symbolic", "transport", 16],
-                tram_stop: ["tram-symbolic", "transport", 16],
+                tram_stop: ["@station", "transport", 12],
             },
             shop: {
                 alcohol: ["drinks-symbolic", "generic"],
@@ -460,6 +477,7 @@ export const DEFS = {
                 hardware: ["build-alt-symbolic", "generic"],
                 ice_cream: ["icecream-cone-symbolic", "food"],
                 jewelry: ["anniversary-symbolic", "generic"],
+                locksmith: ["key2-symbolic", "generic"],
                 mall: ["shop-symbolic", "generic", 14],
                 mobile_phone: ["smartphone-symbolic", "generic"],
                 music: ["headphones-symbolic", "generic"],
