@@ -19,47 +19,53 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Format = imports.format;
+import GLib from 'gi://GLib';
+import Soup from 'gi://Soup';
 
-const GLib = imports.gi.GLib;
-const Soup = imports.gi.Soup;
-
-const Application = imports.application;
-const HTTP = imports.http;
-const PhotonParser = imports.photonParser;
-const Service = imports.service;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import * as HTTP from './http.js';
+import * as PhotonUtils from './photonUtils.js';
+import * as Utils from './utils.js';
 
 // HTTP session timeout (in seconds)
 const TIMEOUT = 5;
 
-var PhotonGeocode = class {
-    constructor() {
+export class PhotonGeocode {
+    constructor({ baseUrl, supportedLanguages, attribution, attributionUrl,
+                  additionalParams }) {
         this._session =
             new Soup.Session({ user_agent : 'gnome-maps/' + pkg.version,
                                timeout:     TIMEOUT });
         this._readService();
         this._limit = Application.settings.get('max-search-results');
+        this._baseUrl = baseUrl;
+        this._attribution = attribution;
+        this._attributionUrl = attributionUrl;
+        this._additionalParams = additionalParams;
+
+        const language = Utils.getLanguage();
+
+        if (supportedLanguages?.includes(language))
+            this._language = language;
+        else
+            this._language = null;
     }
 
     search(string, latitude, longitude, cancellable, callback) {
         let url = this._buildURL(string, latitude, longitude);
-        let msg = Soup.Message.new('GET', url);
-        let handler = cancellable.connect(() => {
-            this._session.cancel_message(msg, Soup.Status.CANCELLED);
-        });
-
-        this._session.queue_message(msg, (session, message) => {
-            cancellable.disconnect(handler);
+        let msg = Soup.Message.new('GET', url)
 
+        this._session.send_and_read_async(msg, GLib.PRIORITY_DEFAULT, cancellable,
+                                          (source, res) => {
             if (cancellable.is_cancelled())
                 return;
 
-            if (message.status_code !== Soup.KnownStatusCode.OK) {
-                callback(null, msg.status_code);
+            if (msg.get_status() !== Soup.Status.OK) {
+                callback(null, msg.get_status());
             } else {
                 try {
-                    let result = this._parseMessage(message.response_body.data);
+                    let buffer = this._session.send_and_read_finish(res).get_data();
+                    let result = this._parseMessage(Utils.getBufferText(buffer));
                     if (!result)
                         callback(null, null);
                     else
@@ -72,32 +78,12 @@ var PhotonGeocode = class {
         });
     }
 
-    reverse(latitude, longitude, callback) {
-        let url = this._buildURL(null, latitude, longitude);
-        let msg = Soup.Message.new('GET', url);
-
-        Application.application.mark_busy();
-        this._session.queue_message(msg, (session, message) => {
-            Application.application.unmark_busy();
-            try {
-                let result = this._parseMessage(message.response_body.data);
-                if (!result)
-                    callback(null, null);
-                else
-                    callback(result[0], null);
-            } catch (e) {
-                Utils.debug('Error: ' + e);
-                callback(null, e);
-            }
-        });
-    }
-
     get attribution() {
-        return Service.getService().photonGeocode.attribution;
+        return this._attribution;
     }
 
     get attributionUrl() {
-        return Service.getService().photonGeocode.attributionUrl;
+        return this._attributionUrl;
     }
 
     get name() {
@@ -131,49 +117,26 @@ var PhotonGeocode = class {
     _parseFeature(feature) {
         let [lon, lat] = feature.geometry.coordinates;
 
-        return PhotonParser.parsePlace(lat, lon, feature.properties);
+        return PhotonUtils.parsePlace(lat, lon, feature.properties);
     }
 
     _buildURL(string, latitude, longitude) {
-        let query = new HTTP.Query({ limit: string ? this._limit : 1 });
+        let query = new HTTP.Query({ limit: this._limit,
+                                     q:     string });
 
         if (latitude !== null && longitude != null) {
             query.add('lat', latitude);
             query.add('lon', longitude);
+            if (string)
+                query.add('location_bias_scale', PhotonUtils.LOCATION_BIAS_SCALE);
         }
 
-        if (string)
-            query.add('q', string);
-        else
-            query.add('distance_sort', 'true');
-
         if (this._language)
             query.add('lang', this._language);
 
         if (this._additionalParams)
             this._additionalParams.forEach((p) => query.add(p.key, p.value));
 
-        return Format.vprintf('%s/%s/?%s', [this._baseUrl,
-                                            string ? 'api' : 'reverse',
-                                            query.toString()]);
-    }
-
-    _readService() {
-        let photon = Service.getService().photonGeocode;
-        let language = Utils.getLanguage();
-        let supportedLanguages;
-
-        if (photon) {
-            this._baseUrl = photon.baseUrl;
-            supportedLanguages = photon.supportedLanguages;
-
-            if (photon.additionalParams)
-                this._additionalParams = photon.additionalParams;
-        }
-
-        if (supportedLanguages.includes(language))
-            this._language = language;
-        else
-            this._language = null;
+        return `${this._baseUrl}/api/?${query.toString()}`;
     }
 }
