@@ -30,10 +30,12 @@ import {Location} from './location.js';
 import * as OSMNames from './osmNames.js';
 import {Overpass} from './overpass.js';
 import * as PlaceIcons from './placeIcons.js';
+import {spriteSource} from './mapSource.js';
 import * as URIS from './uris.js';
 import * as Utils from './utils.js';
 
 const _ = gettext.gettext;
+const C_ = gettext.dgettext;
 
 // Matches coordinates string in 'Decimal Degrees' format
 const DECIMAL_COORDINATES_REGEX = (
@@ -133,7 +135,7 @@ export class Place extends GObject.Object {
             );
         }
 
-        return this._name;
+        return this._name ?? this.coordinatesDescription;
     }
 
     set name(name) {
@@ -276,6 +278,27 @@ export class Place extends GObject.Object {
         return this._isCurrentLocation;
     }
 
+    // true if the place is not connected to an OSM object
+    get isRawCoordinates() {
+        return !this._osmType && !this._osmId;
+    }
+
+    get coordinatesDescription() {
+        const lat =
+            this.location.latitude.toLocaleString(undefined,
+                                                  { minimumFractionDigits: 5,
+                                                    maximumFractionDigits: 5 });
+        const lon =
+            this.location.longitude.toLocaleString(undefined,
+                                                   { minimumFractionDigits: 5,
+                                                     maximumFractionDigits: 5 });
+
+        /* Translators: this is a format template string for a pair of raw
+         * coordinates, the comma can be adapted to local conventions if needed.
+         */
+        return C_("coordinates", "%s, %s").format(lat, lon);
+    }
+
     get population() {
         return this.osmTags?.population;
     }
@@ -304,6 +327,10 @@ export class Place extends GObject.Object {
         return this.osmTags?.['brand:wikidata'];
     }
 
+    get networkWikidata() {
+        return this.osmTags?.['network:wikidata'];
+    }
+
     get openingHours() {
         return this.osmTags?.opening_hours ?? this.osmTags?.openingHours;
     }
@@ -352,6 +379,28 @@ export class Place extends GObject.Object {
         return this.osmTags?.name;
     }
 
+    get hiraganaName() {
+        return this.osmTags?.['name:ja-Hira'];
+    }
+
+    /**
+     * Gets an array of objects with {shield, name, network, ref}
+     * from the route_x_[network|ref] tags
+     */
+    get routes() {
+        return [1, 2, 3, 4, 5].map(i => {
+                                   const network =
+                                    this.osmTags?.['route_' + i + '_network'] ?? '';
+
+                                   return { shield:  spriteSource.get_shield_for_network(network),
+                                            name:    this.osmTags?.['route_' + i + '_name'],
+                                            network: network,
+                                            ref:     this.osmTags?.['route_' + i + '_ref']
+                                           }
+                                   })
+                              .filter(e => e.shield);
+    }
+
     /**
      * Most important OSM tag for the place ('amenity', 'shop', and so on).
      */
@@ -361,7 +410,8 @@ export class Place extends GObject.Object {
         if (osmTags) {
             const tag = [
                 'place', 'amenity', 'leisure', 'shop', 'tourism', 'highway',
-                'railway', 'aeroway', 'office', 'building', 'historic', 'barrier'
+                'railway', 'aeroway', 'office', 'building', 'historic', 'barrier',
+                'landuse'
             ].find(key => key in osmTags);
 
             if (tag)
@@ -384,7 +434,8 @@ export class Place extends GObject.Object {
     }
 
     _getIconName() {
-        return PlaceIcons.getIconForPlace(this);
+        return this.isRawCoordinates ? 'pin-location-symbolic' :
+                                        PlaceIcons.getIconForPlace(this);
     }
 
     /**
@@ -405,6 +456,21 @@ export class Place extends GObject.Object {
         return this.osmTags?.['addr:floor'] ?? this.osmTags?.['level:ref'];
     }
 
+    get ref() {
+        return this.osmTags?.ref;
+    }
+
+    /**
+     * Return true if the place is a motorway junction ("highway exit")
+     */
+    get isMotorwayJunction() {
+        return this.osmTags?.highway === 'motorway_junction';
+    }
+
+    get station() {
+        return this.osmTags?.station;
+    }
+
     toJSON() {
         let boundingBox = null;
 
