@@ -21,6 +21,7 @@
 
 import gettext from 'gettext';
 
+import Gio from 'gi://Gio';
 import GWeather from 'gi://GWeather';
 import GLib from 'gi://GLib';
 import Shumate from 'gi://Shumate';
@@ -39,6 +40,7 @@ const _ = gettext.gettext;
 
 export class Motis2 {
     constructor(params) {
+        this._requestCancellable = null
         this._baseUrl = GLib.getenv('MOTIS_BASE_URL') ?? params?.baseUrl;
         this._plan = Application.routingDelegator.transitRouter.plan;
         this._query = Application.routeQuery;
@@ -50,6 +52,13 @@ export class Motis2 {
             throw new Error('must specify baseUrl as an argument');
     }
 
+    cancelCurrentRequest() {
+        if (this._requestCancellable) {
+            this._requestCancellable.cancel();
+            this._requestCancellable = null;
+        }
+    }
+
     fetchFirstResults() {
         // for now, don't handle via locations
         if (this._query.filledPoints.length > 2) {
@@ -66,7 +75,7 @@ export class Motis2 {
 
     _fetch(extendPrevious = false) {
         const query = this._getQuery(extendPrevious);
-        const request = Soup.Message.new('GET', this._baseUrl + '/api/v1/plan?' +
+        const request = Soup.Message.new('GET', this._baseUrl + '/api/v3/plan?' +
                                          query.toString());
 
         // if trying to extend trips, and there was no page cursor, show no results
@@ -80,7 +89,9 @@ export class Motis2 {
 
         request.request_headers.replace('Content-Type', 'application/json');
 
-        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, null,
+        this._requestCancellable = new Gio.Cancellable();
+
+        this._session.send_and_read_async(request, GLib.PRIORITY_DEFAULT, this._requestCancellable,
                                           (source, res) => {
             try {
                 if (request.get_status() !== Soup.Status.OK) {
@@ -97,9 +108,12 @@ export class Motis2 {
 
                     this._parseResult(result, extendPrevious);
                 }
+                this._requestCancellable = null;
             } catch (error) {
-                Utils.debug('Failed to send request: ' + error.msg + ', ' + error.stack);
-                this._plan.requestFailed();
+                if (!error.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED)) {
+                    Utils.debug('Failed to send request: ' + error.msg + ', ' + error.stack);
+                    this._plan.requestFailed();
+                }
             }
         });
     }
@@ -225,7 +239,8 @@ export class Motis2 {
 
         const polyline =
             leg?.legGeometry?.points ?
-            this._getEncodedPolyline(leg.legGeometry.points) : undefined;
+            this._getEncodedPolyline(leg.legGeometry.points,
+                                     leg.legGeometry.precision) : undefined;
 
         const commonLegTimezoneOffset =
             arrivalTimezoneOffset === departureTimezoneOffset ?
@@ -280,13 +295,14 @@ export class Motis2 {
         return fromCoord.distance(toCoord);
     }
 
-    _getEncodedPolyline(polyline) {
+    _getEncodedPolyline(polyline, precision) {
         if (!this._cachedEncodedPolylines[polyline]) {
             // clear cached entries when above threashhold to prevent overgrowing
             if (Object.values(this._cachedEncodedPolylines).length > 100)
                 this._cachedEncodedPolylines = {};
 
-            this._cachedEncodedPolylines[polyline] = Epaf.decode(polyline, 7);
+            this._cachedEncodedPolylines[polyline] =
+                Epaf.decode(polyline, precision);
         }
 
         return this._cachedEncodedPolylines[polyline];
@@ -318,7 +334,8 @@ export class Motis2 {
             const [type, instruction] =
                 this._getTurnpointTypeAndInstruction(step);
             const coordinate =
-                Epaf.decodeFirstCoordinate(step.polyline.points, 7);
+                Epaf.decodeFirstCoordinate(step.polyline.points,
+                                           step.polyline.precision);
 
             return new TurnPoint({ type:        type,
                                    distance:    step.distance,
